import java.text.DecimalFormat;
import java.text.FieldPosition;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.TimeZone;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


public class Earthquake implements Comparable<Earthquake> {

	String src="xx";
	String eqid="00000000";
	String version;
	long dateTime;
	float lat, lon;
	float mag, dep;
	short nst;
	String region="Nowhere";
	
	private Earthquake(){
		date.setTimeZone(TimeZone.getTimeZone("UTC"));
	}
	
	@Override
	public int compareTo(Earthquake that){
		return (this.dateTime < that.dateTime)?-1:1;
	}	
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((eqid == null) ? 0 : eqid.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (!(obj instanceof Earthquake)) {
			return false;
		}
		Earthquake other = (Earthquake) obj;
		if (eqid == null) {
			if (other.eqid != null) {
				return false;
			}
		} else if (!eqid.equals(other.eqid)) {
			return false;
		}
		return true;
	}

	private static DecimalFormat 
			coords		= new DecimalFormat( "##0.0000" ),
			magnitude	= new DecimalFormat( "###0.0" ),
			depth		= new DecimalFormat( "###0.00" );
	private static SimpleDateFormat date = new SimpleDateFormat("'\"'EEEE', 'MMMM' 'dd', 'yyyy' 'HH':'mm':'ss' 'zzz'\"'");

	
	// Src, Eqid, Version, Datetime, Lat, Lon, Magnitude, Depth, NST, Region;

	public static Earthquake parseEarthquake(String string){
		Earthquake result = new Earthquake();

		Matcher matcher = Pattern.compile("(\".*?\")|([^,]+)").matcher(string);
		
		
		try {

			matcher.find();	result.src = matcher.group();
			matcher.find();	result.eqid = matcher.group();
			matcher.find();	result.version = matcher.group();
			matcher.find();	result.dateTime = date.parse(matcher.group()).getTime();
			matcher.find();	result.lat = coords.parse(matcher.group()).floatValue();
			matcher.find();	result.lon = coords.parse(matcher.group()).floatValue();
			matcher.find();	result.mag = magnitude.parse(matcher.group()).floatValue();
			matcher.find();	result.dep = depth.parse(matcher.group()).floatValue();
			matcher.find();	result.nst = Short.parseShort(matcher.group().trim());
			matcher.find();	result.region = matcher.group();	

		} catch (ParseException e) {
			e.printStackTrace();
		} catch (NumberFormatException e) {
			e.printStackTrace();
		}

	return result;
	}
	
	@Override
	public String toString(){
		StringBuffer buf = new StringBuffer();
		
							buf.append(src);
		buf.append(',');	buf.append(eqid);
		buf.append(',');	buf.append(version);
		buf.append(',');	date.format(dateTime, buf, new FieldPosition(0));
		buf.append(',');	coords.format(lat, buf, new FieldPosition(0));
		buf.append(',');	coords.format(lon, buf, new FieldPosition(0));
		buf.append(',');	magnitude.format(mag, buf, new FieldPosition(0));
		buf.append(',');	depth.format(dep, buf, new FieldPosition(0));
		buf.append(',');	buf.append(nst);
		buf.append(',');	buf.append(region);
		
		return buf.toString();
		
	}
}
