import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.Collections;
import java.util.LinkedList;
import java.util.ListIterator;

import processing.core.PApplet;
import processing.core.PImage;


public class Earthquaker extends PApplet  {
	
	/***/
	private static final long serialVersionUID = -3413711770924664652L;
	
	final int tickRate = 1000000;
	long ticks;
	boolean paused;
	
	LinkedList<Earthquake> quakes = new LinkedList<Earthquake>();
	ListIterator<Earthquake> quakeIterator;

	public boolean sketchFullScreen() {return false;}
	public int sketchWidth() {return 1200;}
	public int sketchHeight() {return 600;}
	public String sketchRenderer() {return JAVA2D;}
	
	PImage img;

	public void setup(){
		img = loadImage("vector-world-map-v2.2-blank.gif");	
		size(sketchWidth(), sketchHeight(), sketchRenderer());

		frameRate(30);
		ellipseMode(CENTER);
		stroke(0xFFFF0000);
		image(img, 0, 0, width, height);
		tint(0xFF, 0x08);
		
		try {
			BufferedReader dataFile = this.createReader("M1Earthquakes.txt");
			EarthquakeData.loadData(quakes, dataFile);
			dataFile.close();
			
		} catch (IOException e) {
			e.printStackTrace();
		}
			
		
		
		Collections.sort(quakes);
		quakeIterator = quakes.listIterator();
		
		ticks = quakeIterator.next().dateTime;
		
	}
	
	public void draw(){
		if(!paused && quakeIterator.hasNext()){
			Earthquake quake;

			fill(0x80FF0000);
			quakeIterator.previous();
			while(quakeIterator.hasNext() && (quake = quakeIterator.next()).dateTime < ticks){
				float rad = map(quake.mag, 0, 10, 0, 100);
				ellipse(map(quake.lon,-180,180,0,sketchWidth()), map(quake.lat,90,-90,0,sketchHeight()), rad, rad);
				println(quake);
			}
			ticks += tickRate;

			image(img, 0, 0, width, height);
			println(ticks);

			fill(0xFF000000);
			rect(0,sketchHeight()-20,sketchWidth()-1,sketchHeight()-1);
			fill(0xFFFF0000);
			text(new java.util.Date(ticks).toString(), 5, sketchHeight()-5);
		}
	}
	
	public void fadeTo(int color){
		final int red = (color >>= 16) & 0x000000FF,
				green = (color >>= 8) & 0x000000FF,
				blue = color & 0x000000FF;
				
		int r,g,b;
		loadPixels();
		  for (int i = 0; i < pixels.length; i++) {
		    r = (pixels[i] >> 16) & 0x000000ff; 
		    g = (pixels[i] >> 8) & 0x000000ff; 
		    b = pixels[i] & 0x000000ff; 
		    pixels[i] = (((r+((red-r)>>3)) << 16) | ((g+((green-g)>>3)) << 8) | (b+((blue-b)>>3)));
		  } 
		  updatePixels();
	}
	
	@Override
	public void mousePressed() {
		if(paused)
			paused = false;
		else 
			paused = true;
	} 
	
	public static void main(String[] args) {
		PApplet.main(Earthquaker.class.getSimpleName());
	}
}
